@@ -20,13 +20,15 @@ from kivy.uix.label import Label
 from kivy.uix.widget import Widget                                                          # type: ignore
 
 
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 
 class ContainerChildrenAutoWidthBehavior:
     """ detect minimum width for the complete display of the textures of all children at opening with animation.
 
-    This mix-in class can be added to any type of container or layout widget.
+    This mix-in class can be added to any type of container or layout widget for to provide a consistent API
+    with :meth:`.open` and :meth:`.close` methods, a :meth:`.on_complete_opened` event and a :attr:`.container`
+    attribute.
 
     A `container` attribute will be automatically created for container classes without it.
 
@@ -45,10 +47,16 @@ class ContainerChildrenAutoWidthBehavior:
     The window width gets bound to the container width for to ensure proper displaying if
     the window width changes.
 
+    :Events:
+        `on_complete_opened`:
+            Fired when the container width animation is finished or stopped because all children are fully visible.
+
     """
     container: Widget           #: widget to add the dynamic children to (provided by the widget to be mixed into)
+    dismiss: Callable           #: optional method provided by the widget to be mixed into
     dispatch: Callable          #: event dispatch method, provided by the widget to be mixed into
     opacity: float              #: opacity of the widget to be mixed into
+    parent: Widget              #: parent of this widget/container.
     width: float                #: width of the widget to be mixed into (mostly a parent of self.container)
 
     auto_width_anim_duration: float = NumericProperty(0.9)
@@ -94,26 +102,43 @@ class ContainerChildrenAutoWidthBehavior:
         self.register_event_type('on_complete_opened')  # pylint: disable=maybe-no-member
         super().__init__(**kwargs)
 
+    def close(self, *_args, **_kwargs):
+        """ close/dismiss container/layout (ae.gui_app popup handling compatibility for all GUI frameworks).
+
+        :param _args:           unused argument (for to have compatible signature for DropDown/Popup/ModalView widgets).
+        :param _kwargs:         unused argument (for to have compatible signature for DropDown/Popup/ModalView widgets).
+        """
+        try:
+            # noinspection PyUnresolvedReferences
+            super().close(*_args, **_kwargs)
+        except AttributeError:
+            try:
+                self.dismiss(*_args, **_kwargs)
+            except AttributeError:
+                if self.parent and self in self.parent.children:
+                    self.parent.remove_widget(self)
+
     def on_complete_opened(self):
         """ dispatch event when opening and width got determined. """
 
     def open(self, *_args, **kwargs):
         """ start optional open animation after calling open method if exists in inheriting container/layout widget.
 
-        :param _args:           unused argument (for to have compatible signature for Popup/ModalView widgets).
+        :param _args:           unused argument (for to have compatible signature for Popup/ModalView and DropDown
+                                widgets passing the parent widget).
         :param kwargs:          extra arguments that are removed before to be passed to the inheriting open method:
 
                                 * 'open_width_animation': `False` will disable the `width` animation (default=True).
         """
         anim_width = kwargs.pop('open_width_animation', True)
 
+        if not hasattr(super(), 'container'):
+            self.container = getattr(self, '_container', self)  # Popup has _container attribute, BoxLayout=self
+
         if callable(getattr(super(), 'open', None)):
             # noinspection PyUnresolvedReferences
             super().open(*_args, **kwargs)      # pylint: disable=maybe-no-member
 
-        if not hasattr(super(), 'container'):
-            self.container = getattr(self, '_container', self)  # Popup has _container attribute, BoxLayout=self
-
         if anim_width:
             container_max_width = Window.width - self.auto_width_window_padding
             self._width_anim = Animation(opacity=1.0, width=container_max_width,
